--[[
	Easy run stats library.
	Prints FPS and delta-time.
	
	Methods:
		Update(DeltaTime)			Send an update. Should be called every love.update()
		
		Display(x, y)				Display pre-formatted text at (x, y) via love.graphics.print
		
		DisplayCustom(format, x, y)	Display custom-formatted text at (x, y)
			To format:
				Put "<FPS>" where you want the FPS value to display in text
				Put "<DT>" where you want render time to display in text
				
				Default example:
					"FPS: <FPS> | dt: <DT>ms"
--]]

local RunStats = {}

local DELTA = 0
local TICKS = 0
local AVG_FPS = 0
local TIMER = 0

local AVG_FPS_DISPLAY = "..."
local DELTA_DISPLAY = "0ms"

function RunStats:Update(Delta)
	DELTA = Delta
	DELTA_DISPLAY = math.floor(DELTA * 1000)
	AVG_FPS = AVG_FPS + (1/DELTA)
	TICKS = TICKS + 1
	TIMER = TIMER + Delta
	if TIMER >= 1 then
		TIMER = TIMER - 1
		AVG_FPS_DISPLAY = string.format("%03d", math.floor(AVG_FPS / TICKS))
		AVG_FPS = 0
		TICKS = 0
	end
end

function RunStats:DisplayCustom(Text, x, y)
	local Text = Text or "FPS: <FPS> | dt: <DT>ms"
	local x = x or 0
	local y = y or 0
	
	local Text = Text:gsub("<FPS>", AVG_FPS_DISPLAY):gsub("<DT>", DELTA_DISPLAY)
	love.graphics.print(Text, x, y)
end

function RunStats:Display(x, y)
	RunStats:DisplayCustom(nil, x, y)
end

return RunStats